@@ -1,8 +1,8 @@
-from metakernel import Magic, option
-from IPython.display import IFrame
-    
+from metakernel import Magic
+
+
 class BrainMagic(Magic):
-    def cell_brain(self):
+    def cell_brain(self) -> None:
         """
         %%brain - run a cell as brain control code
         for a calysto.simulation.
@@ -20,21 +20,26 @@ robot = get_robot()
 def brain():
 """
         post_code = """robot.brain = brain"""
-        new_code = ("    ".join(line + "\n" for line in text.split("\n")))
+        new_code = "    ".join(line + "\n" for line in text.split("\n"))
         self.code = pre_code + new_code + post_code
 
-def register_magics(kernel):
+
+def register_magics(kernel) -> None:
     kernel.register_magics(BrainMagic)
 
-def register_ipython_magics():
-    from metakernel import IPythonKernel
+
+def register_ipython_magics() -> None:
     from IPython.core.magic import register_cell_magic
+
+    from metakernel import IPythonKernel
+
     kernel = IPythonKernel()
     magic = BrainMagic(kernel)
 
     @register_cell_magic
     def brain(line, cell):
-        from IPython import get_ipython
+        from IPython import get_ipython  # type:ignore[attr-defined]
+
         ipkernel = get_ipython()
         magic.code = cell
         magic.cell_brain()
