@@ -1,32 +1,25 @@
 # Copyright (c) Metakernel Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from metakernel import Magic
-import urllib
-try:
-    import urlparse
-except ImportError:
-    from urllib import parse as urlparse
 import os
+import urllib.parse as urlparse
+import urllib.request
+
+from metakernel import Magic
+
+
+def download(url, filename):
+    g = urllib.request.urlopen(url)
+    with open(filename, "wb") as f:
+        f.write(g.read())
 
-try:
-    urllib.URLopener
-    def download(url, filename):
-        opener = urllib.URLopener()
-        opener.retrieve(url, filename)
-except: # python3
-    def download(url, filename):
-        g = urllib.request.urlopen(url)
-        with open(filename, 'wb') as f:
-            f.write(g.read())
 
 class InstallMagicMagic(Magic):
-
-    def line_install_magic(self, url):
+    def line_install_magic(self, url) -> None:
         """
         %install_magic URL - download and install magic from URL
 
-        This line magic will copy the file at the URL into your 
+        This line magic will copy the file at the URL into your
         personal magic folder.
 
         Example:
@@ -34,17 +27,17 @@ class InstallMagicMagic(Magic):
 
         """
         parts = urlparse.urlsplit(url)
-        #('http', 'example.com', '/somefile.zip', '', '')
+        # ('http', 'example.com', '/somefile.zip', '', '')
         path = parts[2]
         filename = os.path.basename(path)
         magic_filename = os.path.join(self.kernel.get_local_magics_dir(), filename)
         try:
             download(url, magic_filename)
-            self.kernel.Print("Downloaded '%s'." % magic_filename)
+            self.kernel.Print(f"Downloaded '{magic_filename}'.")
             self.code = "%reload_magics\n" + self.code
         except Exception as e:
             self.kernel.Error(str(e))
 
-def register_magics(kernel):
-    kernel.register_magics(InstallMagicMagic)
 
+def register_magics(kernel) -> None:
+    kernel.register_magics(InstallMagicMagic)
