@@ -1,12 +1,13 @@
 # Copyright (c) Metakernel Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from metakernel import Magic
 import time
 
-class TimeMagic(Magic):
+from metakernel import Magic
 
-    def cell_time(self):
+
+class TimeMagic(Magic):
+    def cell_time(self) -> None:
         """
         %%time - show time to run cell
 
@@ -29,5 +30,5 @@ class TimeMagic(Magic):
         return retval
 
 
-def register_magics(kernel):
+def register_magics(kernel) -> None:
     kernel.register_magics(TimeMagic)
